Index: src/macro-assembler.h |
diff --git a/src/macro-assembler.h b/src/macro-assembler.h |
index b59fd3b94d43fa54f2bfe6fe96dc9fc8356a3ad4..166ac428b57767f82f452a2870f93c8c34fac0a2 100644 |
--- a/src/macro-assembler.h |
+++ b/src/macro-assembler.h |
@@ -27,8 +27,10 @@ enum AllocationFlags { |
SIZE_IN_WORDS = 1 << 2, |
// Align the allocation to a multiple of kDoubleSize |
DOUBLE_ALIGNMENT = 1 << 3, |
- // Directly allocate in old space |
- PRETENURE = 1 << 4, |
+ // Directly allocate in old pointer space |
+ PRETENURE_OLD_POINTER_SPACE = 1 << 4, |
+ // Directly allocate in old data space |
+ PRETENURE_OLD_DATA_SPACE = 1 << 5 |
}; |
@@ -249,8 +251,11 @@ class AllocationUtils { |
public: |
static ExternalReference GetAllocationTopReference( |
Isolate* isolate, AllocationFlags flags) { |
- if ((flags & PRETENURE) != 0) { |
- return ExternalReference::old_space_allocation_top_address(isolate); |
+ if ((flags & PRETENURE_OLD_POINTER_SPACE) != 0) { |
+ return ExternalReference::old_pointer_space_allocation_top_address( |
+ isolate); |
+ } else if ((flags & PRETENURE_OLD_DATA_SPACE) != 0) { |
+ return ExternalReference::old_data_space_allocation_top_address(isolate); |
} |
return ExternalReference::new_space_allocation_top_address(isolate); |
} |
@@ -258,8 +263,12 @@ class AllocationUtils { |
static ExternalReference GetAllocationLimitReference( |
Isolate* isolate, AllocationFlags flags) { |
- if ((flags & PRETENURE) != 0) { |
- return ExternalReference::old_space_allocation_limit_address(isolate); |
+ if ((flags & PRETENURE_OLD_POINTER_SPACE) != 0) { |
+ return ExternalReference::old_pointer_space_allocation_limit_address( |
+ isolate); |
+ } else if ((flags & PRETENURE_OLD_DATA_SPACE) != 0) { |
+ return ExternalReference::old_data_space_allocation_limit_address( |
+ isolate); |
} |
return ExternalReference::new_space_allocation_limit_address(isolate); |
} |